@@ -2,11 +2,18 @@
 #
 # Script to create debian/control for package boost-defaults
 
+
 from deb822 import Deb822
-import re
+import re, sys
 
 gBoostVersion = None
 
+def versionFromSourceName(sourcename):
+    m = re.match("^boost(\d+)\.(\d+)(\.\d+)?$", sourcename)
+    if not m: raise RuntimeError("source name does not match expected pattern: " + sourcename)
+    minor = ".0"
+    if m.lastindex > 2: minor = m.group(3)
+    return ".".join(m.group(1,2)) + minor
 
 class BoostVersion:
     def __init__(self, version):
@@ -46,11 +53,12 @@ def deleteKey(paragraph, key):
 
 def processSourceParagraph(p):
     p['Source'] = 'boost-defaults'
+    p['Vcs-Browser'] = 'https://salsa.debian.org/debian/boost-defaults'
+    p['Vcs-Git'] = 'https://salsa.debian.org/debian/boost-defaults.git'
     p['Build-Depends'] = 'debhelper (>= 9), ' + \
         gBoostVersion.versionedSubPackage('dev') + ' (>= ' + gBoostVersion.SharedObjectVersion + ')'
     deleteKey(p, 'Build-Conflicts')
-    deleteKey(p, 'Vcs-Browser')
-    deleteKey(p, 'Vcs-Svn')
+    deleteKey(p, 'Build-Depends-Indep')
 
 def genericPackageName(pkgName):
     '''Given an input package name of the form x1-x2-...-yVERSION-z,
@@ -63,7 +71,7 @@ def genericPackageName(pkgName):
 
 def dependsLibDev(p, versionedName):
     '''Set package Depends for a library -dev package.'''
-    return 'g++ (>= 4:5-0), g++-5 (>= 5.2.1-11), libstdc++-5-dev (>= 5.2.1-11), ${misc:Depends}, ' + versionedName
+    return '${misc:Depends}, ' + versionedName
 
 def dependsDbg(p, versionedName):
     '''Set package Depends for libboost-dbg.'''
@@ -104,10 +112,12 @@ def printParagraph(p):
     for key in p.keys():
         print "%s: %s" % (key, p[key])
 
-def processControl():
+def processControl(controlfile):
     firstParagraph = True
-    for paragraph in Deb822.iter_paragraphs(open('control')):
+    for paragraph in Deb822.iter_paragraphs(open(controlfile)):
         if firstParagraph:
+            global gBoostVersion
+            gBoostVersion = BoostVersion(versionFromSourceName(paragraph['Source']))
             processSourceParagraph(paragraph)
             printParagraph(paragraph)
             firstParagraph = False
@@ -117,6 +127,7 @@ def processControl():
                 printParagraph(paragraph)
 
 
-
-gBoostVersion = BoostVersion('1.58.0')
-processControl()
+controlfile = 'control'
+if len(sys.argv) > 1:
+    controlfile = sys.argv[1]
+processControl(controlfile)
